# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'tikka/slots/pyqt/resources/gui/widgets/currency.ui'
#
# Created by: PyQt5 UI code generator 5.15.9
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_currencyWidget(object):
    def setupUi(self, currencyWidget):
        currencyWidget.setObjectName("currencyWidget")
        currencyWidget.resize(724, 475)
        self.verticalLayout = QtWidgets.QVBoxLayout(currencyWidget)
        self.verticalLayout.setObjectName("verticalLayout")
        self.refreshButton = QtWidgets.QPushButton(currencyWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.refreshButton.sizePolicy().hasHeightForWidth())
        self.refreshButton.setSizePolicy(sizePolicy)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/icons/refresh_icon"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.refreshButton.setIcon(icon)
        self.refreshButton.setObjectName("refreshButton")
        self.verticalLayout.addWidget(self.refreshButton, 0, QtCore.Qt.AlignRight)
        self.groupBox = QtWidgets.QGroupBox(currencyWidget)
        self.groupBox.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.groupBox.setObjectName("groupBox")
        self.formLayout_2 = QtWidgets.QFormLayout(self.groupBox)
        self.formLayout_2.setLabelAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.formLayout_2.setObjectName("formLayout_2")
        self.nameLabel = QtWidgets.QLabel(self.groupBox)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.nameLabel.setFont(font)
        self.nameLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.nameLabel.setObjectName("nameLabel")
        self.formLayout_2.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.nameLabel)
        self.universalDividendLabel = QtWidgets.QLabel(self.groupBox)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.universalDividendLabel.setFont(font)
        self.universalDividendLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.universalDividendLabel.setObjectName("universalDividendLabel")
        self.formLayout_2.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.universalDividendLabel)
        self.symbolLabel = QtWidgets.QLabel(self.groupBox)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.symbolLabel.setFont(font)
        self.symbolLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.symbolLabel.setObjectName("symbolLabel")
        self.formLayout_2.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.symbolLabel)
        self.monetaryMassLabel = QtWidgets.QLabel(self.groupBox)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.monetaryMassLabel.setFont(font)
        self.monetaryMassLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.monetaryMassLabel.setObjectName("monetaryMassLabel")
        self.formLayout_2.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.monetaryMassLabel)
        self.membersLabel = QtWidgets.QLabel(self.groupBox)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.membersLabel.setFont(font)
        self.membersLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.membersLabel.setObjectName("membersLabel")
        self.formLayout_2.setWidget(4, QtWidgets.QFormLayout.LabelRole, self.membersLabel)
        self.membersValueLabel = QtWidgets.QLabel(self.groupBox)
        self.membersValueLabel.setText("")
        self.membersValueLabel.setObjectName("membersValueLabel")
        self.formLayout_2.setWidget(4, QtWidgets.QFormLayout.FieldRole, self.membersValueLabel)
        self.universalDividendValueLabel = QtWidgets.QLabel(self.groupBox)
        self.universalDividendValueLabel.setText("")
        self.universalDividendValueLabel.setObjectName("universalDividendValueLabel")
        self.formLayout_2.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.universalDividendValueLabel)
        self.monetaryMassValueLabel = QtWidgets.QLabel(self.groupBox)
        self.monetaryMassValueLabel.setText("")
        self.monetaryMassValueLabel.setObjectName("monetaryMassValueLabel")
        self.formLayout_2.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.monetaryMassValueLabel)
        self.symbolValueLabel = QtWidgets.QLabel(self.groupBox)
        self.symbolValueLabel.setText("")
        self.symbolValueLabel.setObjectName("symbolValueLabel")
        self.formLayout_2.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.symbolValueLabel)
        self.nameValueLabel = QtWidgets.QLabel(self.groupBox)
        self.nameValueLabel.setText("")
        self.nameValueLabel.setObjectName("nameValueLabel")
        self.formLayout_2.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.nameValueLabel)
        self.verticalLayout.addWidget(self.groupBox)
        self.errorLabel = QtWidgets.QLabel(currencyWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.errorLabel.sizePolicy().hasHeightForWidth())
        self.errorLabel.setSizePolicy(sizePolicy)
        self.errorLabel.setStyleSheet("color: red")
        self.errorLabel.setText("")
        self.errorLabel.setAlignment(QtCore.Qt.AlignCenter)
        self.errorLabel.setObjectName("errorLabel")
        self.verticalLayout.addWidget(self.errorLabel)
        self.groupBox_2 = QtWidgets.QGroupBox(currencyWidget)
        self.groupBox_2.setObjectName("groupBox_2")
        self.formLayout_3 = QtWidgets.QFormLayout(self.groupBox_2)
        self.formLayout_3.setObjectName("formLayout_3")
        self.expectedBlockDurationLabel = QtWidgets.QLabel(self.groupBox_2)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.expectedBlockDurationLabel.setFont(font)
        self.expectedBlockDurationLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.expectedBlockDurationLabel.setObjectName("expectedBlockDurationLabel")
        self.formLayout_3.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.expectedBlockDurationLabel)
        self.expectedBlockDurationValueLabel = QtWidgets.QLabel(self.groupBox_2)
        self.expectedBlockDurationValueLabel.setText("")
        self.expectedBlockDurationValueLabel.setObjectName("expectedBlockDurationValueLabel")
        self.formLayout_3.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.expectedBlockDurationValueLabel)
        self.expectedEpochDurationLabel = QtWidgets.QLabel(self.groupBox_2)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.expectedEpochDurationLabel.setFont(font)
        self.expectedEpochDurationLabel.setObjectName("expectedEpochDurationLabel")
        self.formLayout_3.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.expectedEpochDurationLabel)
        self.expectedEpochDurationValueLabel = QtWidgets.QLabel(self.groupBox_2)
        self.expectedEpochDurationValueLabel.setText("")
        self.expectedEpochDurationValueLabel.setObjectName("expectedEpochDurationValueLabel")
        self.formLayout_3.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.expectedEpochDurationValueLabel)
        self.verticalLayout.addWidget(self.groupBox_2)

        self.retranslateUi(currencyWidget)
        QtCore.QMetaObject.connectSlotsByName(currencyWidget)

    def retranslateUi(self, currencyWidget):
        #  _translate = QtCore.QCoreApplication.translate
        currencyWidget.setWindowTitle(_("Currency parameters"))
        self.refreshButton.setText(_("Refresh"))
        self.groupBox.setTitle(_("Currency"))
        self.nameLabel.setText(_("Name"))
        self.universalDividendLabel.setText(_("Universal Dividend"))
        self.symbolLabel.setText(_("Symbol"))
        self.monetaryMassLabel.setText(_("Monetary Mass"))
        self.membersLabel.setText(_("Members"))
        self.groupBox_2.setTitle(_("Blockchain"))
        self.expectedBlockDurationLabel.setText(_("Expected Block duration"))
        self.expectedEpochDurationLabel.setText(_("Expected Epoch duration"))
import tikka.slots.pyqt.resources.icons.index_rc
