# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'tikka/slots/pyqt/resources/gui/widgets/technical_committee_proposal.ui'
#
# Created by: PyQt5 UI code generator 5.15.9
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_TechnicalCommitteeProposalWidget(object):
    def setupUi(self, TechnicalCommitteeProposalWidget):
        TechnicalCommitteeProposalWidget.setObjectName("TechnicalCommitteeProposalWidget")
        TechnicalCommitteeProposalWidget.resize(675, 227)
        self.gridLayout_2 = QtWidgets.QGridLayout(TechnicalCommitteeProposalWidget)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.proposalGroupBox = QtWidgets.QGroupBox(TechnicalCommitteeProposalWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.proposalGroupBox.sizePolicy().hasHeightForWidth())
        self.proposalGroupBox.setSizePolicy(sizePolicy)
        self.proposalGroupBox.setObjectName("proposalGroupBox")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.proposalGroupBox)
        self.verticalLayout.setObjectName("verticalLayout")
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.callGroupBox = QtWidgets.QGroupBox(self.proposalGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.callGroupBox.sizePolicy().hasHeightForWidth())
        self.callGroupBox.setSizePolicy(sizePolicy)
        self.callGroupBox.setObjectName("callGroupBox")
        self.formLayout_2 = QtWidgets.QFormLayout(self.callGroupBox)
        self.formLayout_2.setLabelAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.formLayout_2.setObjectName("formLayout_2")
        self.callIndexLabel = QtWidgets.QLabel(self.callGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.callIndexLabel.sizePolicy().hasHeightForWidth())
        self.callIndexLabel.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.callIndexLabel.setFont(font)
        self.callIndexLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.callIndexLabel.setObjectName("callIndexLabel")
        self.formLayout_2.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.callIndexLabel)
        self.callIndexValueLabel = QtWidgets.QLabel(self.callGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.callIndexValueLabel.sizePolicy().hasHeightForWidth())
        self.callIndexValueLabel.setSizePolicy(sizePolicy)
        self.callIndexValueLabel.setObjectName("callIndexValueLabel")
        self.formLayout_2.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.callIndexValueLabel)
        self.callHashLabel = QtWidgets.QLabel(self.callGroupBox)
        self.callHashLabel.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.callHashLabel.sizePolicy().hasHeightForWidth())
        self.callHashLabel.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.callHashLabel.setFont(font)
        self.callHashLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.callHashLabel.setObjectName("callHashLabel")
        self.formLayout_2.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.callHashLabel)
        self.callHashValueLabel = QtWidgets.QLabel(self.callGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.callHashValueLabel.sizePolicy().hasHeightForWidth())
        self.callHashValueLabel.setSizePolicy(sizePolicy)
        self.callHashValueLabel.setObjectName("callHashValueLabel")
        self.formLayout_2.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.callHashValueLabel)
        self.callModuleLabel = QtWidgets.QLabel(self.callGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.callModuleLabel.sizePolicy().hasHeightForWidth())
        self.callModuleLabel.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.callModuleLabel.setFont(font)
        self.callModuleLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.callModuleLabel.setObjectName("callModuleLabel")
        self.formLayout_2.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.callModuleLabel)
        self.callModuleValueLabel = QtWidgets.QLabel(self.callGroupBox)
        self.callModuleValueLabel.setObjectName("callModuleValueLabel")
        self.formLayout_2.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.callModuleValueLabel)
        self.callFunctionLabel = QtWidgets.QLabel(self.callGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.callFunctionLabel.sizePolicy().hasHeightForWidth())
        self.callFunctionLabel.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.callFunctionLabel.setFont(font)
        self.callFunctionLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.callFunctionLabel.setObjectName("callFunctionLabel")
        self.formLayout_2.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.callFunctionLabel)
        self.callFunctionValueLabel = QtWidgets.QLabel(self.callGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.callFunctionValueLabel.sizePolicy().hasHeightForWidth())
        self.callFunctionValueLabel.setSizePolicy(sizePolicy)
        self.callFunctionValueLabel.setObjectName("callFunctionValueLabel")
        self.formLayout_2.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.callFunctionValueLabel)
        self.callArgumentsLabel = QtWidgets.QLabel(self.callGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.callArgumentsLabel.sizePolicy().hasHeightForWidth())
        self.callArgumentsLabel.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.callArgumentsLabel.setFont(font)
        self.callArgumentsLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.callArgumentsLabel.setObjectName("callArgumentsLabel")
        self.formLayout_2.setWidget(4, QtWidgets.QFormLayout.LabelRole, self.callArgumentsLabel)
        self.callArgumentsValueLabel = QtWidgets.QLabel(self.callGroupBox)
        self.callArgumentsValueLabel.setObjectName("callArgumentsValueLabel")
        self.formLayout_2.setWidget(4, QtWidgets.QFormLayout.FieldRole, self.callArgumentsValueLabel)
        self.horizontalLayout_4.addWidget(self.callGroupBox)
        self.votingGroupBox = QtWidgets.QGroupBox(self.proposalGroupBox)
        self.votingGroupBox.setObjectName("votingGroupBox")
        self.formLayout = QtWidgets.QFormLayout(self.votingGroupBox)
        self.formLayout.setLabelAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.formLayout.setObjectName("formLayout")
        self.votingIndexLabel = QtWidgets.QLabel(self.votingGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.votingIndexLabel.sizePolicy().hasHeightForWidth())
        self.votingIndexLabel.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.votingIndexLabel.setFont(font)
        self.votingIndexLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.votingIndexLabel.setObjectName("votingIndexLabel")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.votingIndexLabel)
        self.votingIndexValueLabel = QtWidgets.QLabel(self.votingGroupBox)
        self.votingIndexValueLabel.setObjectName("votingIndexValueLabel")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.votingIndexValueLabel)
        self.votingThresholdLabel = QtWidgets.QLabel(self.votingGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.votingThresholdLabel.sizePolicy().hasHeightForWidth())
        self.votingThresholdLabel.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.votingThresholdLabel.setFont(font)
        self.votingThresholdLabel.setObjectName("votingThresholdLabel")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.votingThresholdLabel)
        self.votingThresholdValueLabel = QtWidgets.QLabel(self.votingGroupBox)
        self.votingThresholdValueLabel.setObjectName("votingThresholdValueLabel")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.votingThresholdValueLabel)
        self.votingAyesValueLabel = QtWidgets.QLabel(self.votingGroupBox)
        self.votingAyesValueLabel.setObjectName("votingAyesValueLabel")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.votingAyesValueLabel)
        self.votingNaysValueLabel = QtWidgets.QLabel(self.votingGroupBox)
        self.votingNaysValueLabel.setObjectName("votingNaysValueLabel")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.votingNaysValueLabel)
        self.votingEndLabel = QtWidgets.QLabel(self.votingGroupBox)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.votingEndLabel.setFont(font)
        self.votingEndLabel.setObjectName("votingEndLabel")
        self.formLayout.setWidget(5, QtWidgets.QFormLayout.LabelRole, self.votingEndLabel)
        self.votingEndValueLabel = QtWidgets.QLabel(self.votingGroupBox)
        self.votingEndValueLabel.setObjectName("votingEndValueLabel")
        self.formLayout.setWidget(5, QtWidgets.QFormLayout.FieldRole, self.votingEndValueLabel)
        self.yesButton = QtWidgets.QPushButton(self.votingGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.yesButton.sizePolicy().hasHeightForWidth())
        self.yesButton.setSizePolicy(sizePolicy)
        self.yesButton.setObjectName("yesButton")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.yesButton)
        self.noButton = QtWidgets.QPushButton(self.votingGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.noButton.sizePolicy().hasHeightForWidth())
        self.noButton.setSizePolicy(sizePolicy)
        self.noButton.setObjectName("noButton")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.noButton)
        self.horizontalLayout_4.addWidget(self.votingGroupBox)
        self.verticalLayout.addLayout(self.horizontalLayout_4)
        self.gridLayout_2.addWidget(self.proposalGroupBox, 0, 0, 1, 1)

        self.retranslateUi(TechnicalCommitteeProposalWidget)
        QtCore.QMetaObject.connectSlotsByName(TechnicalCommitteeProposalWidget)

    def retranslateUi(self, TechnicalCommitteeProposalWidget):
        #  _translate = QtCore.QCoreApplication.translate
        TechnicalCommitteeProposalWidget.setWindowTitle(_("Form"))
        self.proposalGroupBox.setTitle(_("Proposal Hash"))
        self.callGroupBox.setTitle(_("Call"))
        self.callIndexLabel.setText(_("Index"))
        self.callIndexValueLabel.setText(_("0"))
        self.callHashLabel.setText(_("Hash"))
        self.callHashValueLabel.setText(_("xxx"))
        self.callModuleLabel.setText(_("Module"))
        self.callModuleValueLabel.setText(_("TextLabel"))
        self.callFunctionLabel.setText(_("Function"))
        self.callFunctionValueLabel.setText(_("TextLabel"))
        self.callArgumentsLabel.setText(_("Arguments"))
        self.callArgumentsValueLabel.setText(_("TextLabel"))
        self.votingGroupBox.setTitle(_("Voting"))
        self.votingIndexLabel.setText(_("index"))
        self.votingIndexValueLabel.setText(_("0"))
        self.votingThresholdLabel.setText(_("Threshold"))
        self.votingThresholdValueLabel.setText(_("0"))
        self.votingAyesValueLabel.setText(_("TextLabel"))
        self.votingNaysValueLabel.setText(_("TextLabel"))
        self.votingEndLabel.setText(_("End"))
        self.votingEndValueLabel.setText(_("TextLabel"))
        self.yesButton.setText(_("Yes"))
        self.noButton.setText(_("No"))
