# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'tikka/slots/pyqt/resources/gui/widgets/smith.ui'
#
# Created by: PyQt5 UI code generator 5.15.9
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_SmithWidget(object):
    def setupUi(self, SmithWidget):
        SmithWidget.setObjectName("SmithWidget")
        SmithWidget.resize(743, 684)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(SmithWidget.sizePolicy().hasHeightForWidth())
        SmithWidget.setSizePolicy(sizePolicy)
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(SmithWidget)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.label = QtWidgets.QLabel(SmithWidget)
        font = QtGui.QFont()
        font.setItalic(True)
        self.label.setFont(font)
        self.label.setObjectName("label")
        self.verticalLayout_2.addWidget(self.label, 0, QtCore.Qt.AlignHCenter)
        self.gridLayout = QtWidgets.QGridLayout()
        self.gridLayout.setObjectName("gridLayout")
        self.goOnlineButton = QtWidgets.QPushButton(SmithWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.goOnlineButton.sizePolicy().hasHeightForWidth())
        self.goOnlineButton.setSizePolicy(sizePolicy)
        self.goOnlineButton.setObjectName("goOnlineButton")
        self.gridLayout.addWidget(self.goOnlineButton, 2, 2, 1, 1)
        self.authorityValueLabel = QtWidgets.QLabel(SmithWidget)
        self.authorityValueLabel.setText("")
        self.authorityValueLabel.setObjectName("authorityValueLabel")
        self.gridLayout.addWidget(self.authorityValueLabel, 2, 1, 1, 1)
        self.accountComboBox = QtWidgets.QComboBox(SmithWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.accountComboBox.sizePolicy().hasHeightForWidth())
        self.accountComboBox.setSizePolicy(sizePolicy)
        self.accountComboBox.setToolTip("")
        self.accountComboBox.setEditable(False)
        self.accountComboBox.setMinimumContentsLength(0)
        self.accountComboBox.setObjectName("accountComboBox")
        self.gridLayout.addWidget(self.accountComboBox, 0, 1, 1, 1)
        self.accountLabel = QtWidgets.QLabel(SmithWidget)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.accountLabel.setFont(font)
        self.accountLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.accountLabel.setObjectName("accountLabel")
        self.gridLayout.addWidget(self.accountLabel, 0, 0, 1, 1)
        self.membershipLabel = QtWidgets.QLabel(SmithWidget)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.membershipLabel.setFont(font)
        self.membershipLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.membershipLabel.setObjectName("membershipLabel")
        self.gridLayout.addWidget(self.membershipLabel, 1, 0, 1, 1)
        self.membershipValueLabel = QtWidgets.QLabel(SmithWidget)
        self.membershipValueLabel.setText("")
        self.membershipValueLabel.setObjectName("membershipValueLabel")
        self.gridLayout.addWidget(self.membershipValueLabel, 1, 1, 1, 1)
        self.refreshSmithButton = QtWidgets.QPushButton(SmithWidget)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/icons/refresh_icon"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.refreshSmithButton.setIcon(icon)
        self.refreshSmithButton.setObjectName("refreshSmithButton")
        self.gridLayout.addWidget(self.refreshSmithButton, 0, 2, 1, 1)
        self.authorityLabel = QtWidgets.QLabel(SmithWidget)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.authorityLabel.setFont(font)
        self.authorityLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.authorityLabel.setObjectName("authorityLabel")
        self.gridLayout.addWidget(self.authorityLabel, 2, 0, 1, 1)
        self.goOfflineButton = QtWidgets.QPushButton(SmithWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.goOfflineButton.sizePolicy().hasHeightForWidth())
        self.goOfflineButton.setSizePolicy(sizePolicy)
        self.goOfflineButton.setObjectName("goOfflineButton")
        self.gridLayout.addWidget(self.goOfflineButton, 3, 2, 1, 1)
        self.loaderIconLabel = QtWidgets.QLabel(SmithWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.loaderIconLabel.sizePolicy().hasHeightForWidth())
        self.loaderIconLabel.setSizePolicy(sizePolicy)
        self.loaderIconLabel.setMaximumSize(QtCore.QSize(16, 16))
        self.loaderIconLabel.setBaseSize(QtCore.QSize(16, 16))
        self.loaderIconLabel.setText("")
        self.loaderIconLabel.setPixmap(QtGui.QPixmap(":/icons/loader"))
        self.loaderIconLabel.setScaledContents(True)
        self.loaderIconLabel.setAlignment(QtCore.Qt.AlignCenter)
        self.loaderIconLabel.setObjectName("loaderIconLabel")
        self.gridLayout.addWidget(self.loaderIconLabel, 1, 2, 1, 1)
        self.verticalLayout_2.addLayout(self.gridLayout)
        self.validatorNodeGroupBox = QtWidgets.QGroupBox(SmithWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.validatorNodeGroupBox.sizePolicy().hasHeightForWidth())
        self.validatorNodeGroupBox.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.validatorNodeGroupBox.setFont(font)
        self.validatorNodeGroupBox.setAutoFillBackground(False)
        self.validatorNodeGroupBox.setObjectName("validatorNodeGroupBox")
        self.formLayout = QtWidgets.QFormLayout(self.validatorNodeGroupBox)
        self.formLayout.setLabelAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.formLayout.setObjectName("formLayout")
        self.urlLabel = QtWidgets.QLabel(self.validatorNodeGroupBox)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.urlLabel.setFont(font)
        self.urlLabel.setObjectName("urlLabel")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.urlLabel)
        self.sessionKeysLabel = QtWidgets.QLabel(self.validatorNodeGroupBox)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.sessionKeysLabel.setFont(font)
        self.sessionKeysLabel.setObjectName("sessionKeysLabel")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.sessionKeysLabel)
        self.urlValueLabel = QtWidgets.QLabel(self.validatorNodeGroupBox)
        self.urlValueLabel.setText("")
        self.urlValueLabel.setObjectName("urlValueLabel")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.urlValueLabel)
        self.rotateKeysButton = QtWidgets.QPushButton(self.validatorNodeGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.rotateKeysButton.sizePolicy().hasHeightForWidth())
        self.rotateKeysButton.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.rotateKeysButton.setFont(font)
        self.rotateKeysButton.setObjectName("rotateKeysButton")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.rotateKeysButton)
        self.publishKeysButton = QtWidgets.QPushButton(self.validatorNodeGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.publishKeysButton.sizePolicy().hasHeightForWidth())
        self.publishKeysButton.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.publishKeysButton.setFont(font)
        self.publishKeysButton.setObjectName("publishKeysButton")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.publishKeysButton)
        self.sessionKeysTextBrowser = QtWidgets.QTextBrowser(self.validatorNodeGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.sessionKeysTextBrowser.sizePolicy().hasHeightForWidth())
        self.sessionKeysTextBrowser.setSizePolicy(sizePolicy)
        self.sessionKeysTextBrowser.setMaximumSize(QtCore.QSize(16777215, 50))
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.sessionKeysTextBrowser.setFont(font)
        self.sessionKeysTextBrowser.setObjectName("sessionKeysTextBrowser")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.sessionKeysTextBrowser)
        self.verticalLayout_2.addWidget(self.validatorNodeGroupBox)
        self.errorLabel = QtWidgets.QLabel(SmithWidget)
        self.errorLabel.setStyleSheet("color: red;")
        self.errorLabel.setText("")
        self.errorLabel.setAlignment(QtCore.Qt.AlignCenter)
        self.errorLabel.setObjectName("errorLabel")
        self.verticalLayout_2.addWidget(self.errorLabel)
        self.acceptInvitationButton = QtWidgets.QPushButton(SmithWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.acceptInvitationButton.sizePolicy().hasHeightForWidth())
        self.acceptInvitationButton.setSizePolicy(sizePolicy)
        self.acceptInvitationButton.setObjectName("acceptInvitationButton")
        self.verticalLayout_2.addWidget(self.acceptInvitationButton)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.inviteButton = QtWidgets.QPushButton(SmithWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.inviteButton.sizePolicy().hasHeightForWidth())
        self.inviteButton.setSizePolicy(sizePolicy)
        self.inviteButton.setObjectName("inviteButton")
        self.horizontalLayout_2.addWidget(self.inviteButton)
        self.inviteAccountComboBox = QtWidgets.QComboBox(SmithWidget)
        self.inviteAccountComboBox.setObjectName("inviteAccountComboBox")
        self.horizontalLayout_2.addWidget(self.inviteAccountComboBox)
        self.verticalLayout_2.addLayout(self.horizontalLayout_2)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.certifyButton = QtWidgets.QPushButton(SmithWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.certifyButton.sizePolicy().hasHeightForWidth())
        self.certifyButton.setSizePolicy(sizePolicy)
        self.certifyButton.setObjectName("certifyButton")
        self.horizontalLayout.addWidget(self.certifyButton)
        self.certifySmithComboBox = QtWidgets.QComboBox(SmithWidget)
        self.certifySmithComboBox.setObjectName("certifySmithComboBox")
        self.horizontalLayout.addWidget(self.certifySmithComboBox)
        self.verticalLayout_2.addLayout(self.horizontalLayout)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.certifiersGroupBox = QtWidgets.QGroupBox(SmithWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.certifiersGroupBox.sizePolicy().hasHeightForWidth())
        self.certifiersGroupBox.setSizePolicy(sizePolicy)
        self.certifiersGroupBox.setObjectName("certifiersGroupBox")
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout(self.certifiersGroupBox)
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.certifiersListWidget = QtWidgets.QListWidget(self.certifiersGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.certifiersListWidget.sizePolicy().hasHeightForWidth())
        self.certifiersListWidget.setSizePolicy(sizePolicy)
        self.certifiersListWidget.setObjectName("certifiersListWidget")
        self.horizontalLayout_4.addWidget(self.certifiersListWidget)
        self.horizontalLayout_3.addWidget(self.certifiersGroupBox)
        self.certifiedGroupBox = QtWidgets.QGroupBox(SmithWidget)
        self.certifiedGroupBox.setObjectName("certifiedGroupBox")
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout(self.certifiedGroupBox)
        self.horizontalLayout_5.setObjectName("horizontalLayout_5")
        self.certifiedListWidget = QtWidgets.QListWidget(self.certifiedGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.certifiedListWidget.sizePolicy().hasHeightForWidth())
        self.certifiedListWidget.setSizePolicy(sizePolicy)
        self.certifiedListWidget.setObjectName("certifiedListWidget")
        self.horizontalLayout_5.addWidget(self.certifiedListWidget)
        self.horizontalLayout_3.addWidget(self.certifiedGroupBox)
        self.verticalLayout_2.addLayout(self.horizontalLayout_3)

        self.retranslateUi(SmithWidget)
        QtCore.QMetaObject.connectSlotsByName(SmithWidget)
        SmithWidget.setTabOrder(self.accountComboBox, self.refreshSmithButton)
        SmithWidget.setTabOrder(self.refreshSmithButton, self.rotateKeysButton)
        SmithWidget.setTabOrder(self.rotateKeysButton, self.publishKeysButton)
        SmithWidget.setTabOrder(self.publishKeysButton, self.sessionKeysTextBrowser)

    def retranslateUi(self, SmithWidget):
        #  _translate = QtCore.QCoreApplication.translate
        SmithWidget.setWindowTitle(_("Smith"))
        self.label.setText(_("Select an account with a validated identity and a wallet"))
        self.goOnlineButton.setText(_("Go online"))
        self.accountLabel.setText(_("Account"))
        self.membershipLabel.setText(_("Smith Membership"))
        self.refreshSmithButton.setToolTip(_("Refresh nodes from network"))
        self.refreshSmithButton.setText(_("Refresh"))
        self.authorityLabel.setText(_("Authority"))
        self.goOfflineButton.setText(_("Go offline"))
        self.validatorNodeGroupBox.setTitle(_("Validator node"))
        self.urlLabel.setText(_("Url"))
        self.sessionKeysLabel.setText(_("Session keys"))
        self.rotateKeysButton.setText(_("Rotate keys"))
        self.publishKeysButton.setText(_("Publish keys"))
        self.acceptInvitationButton.setText(_("Accept invitation"))
        self.inviteButton.setText(_("Invite Member"))
        self.certifyButton.setText(_("Certify"))
        self.certifiersGroupBox.setTitle(_("Certifiers"))
        self.certifiedGroupBox.setTitle(_("Certified"))
import tikka.slots.pyqt.resources.icons.index_rc
