# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'tikka/slots/pyqt/resources/gui/windows/scan_qrcode.ui'
#
# Created by: PyQt5 UI code generator 5.15.9
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_ScanQRCodeDialog(object):
    def setupUi(self, ScanQRCodeDialog):
        ScanQRCodeDialog.setObjectName("ScanQRCodeDialog")
        ScanQRCodeDialog.resize(679, 93)
        self.verticalLayout = QtWidgets.QVBoxLayout(ScanQRCodeDialog)
        self.verticalLayout.setObjectName("verticalLayout")
        self.formLayout = QtWidgets.QFormLayout()
        self.formLayout.setObjectName("formLayout")
        self.addressLabel = QtWidgets.QLabel(ScanQRCodeDialog)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.addressLabel.setFont(font)
        self.addressLabel.setObjectName("addressLabel")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.addressLabel)
        self.addressValueLabel = QtWidgets.QLabel(ScanQRCodeDialog)
        self.addressValueLabel.setText("")
        self.addressValueLabel.setTextInteractionFlags(QtCore.Qt.LinksAccessibleByMouse|QtCore.Qt.TextSelectableByKeyboard|QtCore.Qt.TextSelectableByMouse)
        self.addressValueLabel.setObjectName("addressValueLabel")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.addressValueLabel)
        self.verticalLayout.addLayout(self.formLayout)
        self.errorLabel = QtWidgets.QLabel(ScanQRCodeDialog)
        self.errorLabel.setStyleSheet("color: rgb(255, 0, 0)")
        self.errorLabel.setObjectName("errorLabel")
        self.verticalLayout.addWidget(self.errorLabel, 0, QtCore.Qt.AlignHCenter)
        self.buttonBox = QtWidgets.QDialogButtonBox(ScanQRCodeDialog)
        self.buttonBox.setEnabled(True)
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.Cancel|QtWidgets.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName("buttonBox")
        self.verticalLayout.addWidget(self.buttonBox, 0, QtCore.Qt.AlignHCenter)

        self.retranslateUi(ScanQRCodeDialog)
        self.buttonBox.accepted.connect(ScanQRCodeDialog.accept) # type: ignore
        self.buttonBox.rejected.connect(ScanQRCodeDialog.reject) # type: ignore
        QtCore.QMetaObject.connectSlotsByName(ScanQRCodeDialog)

    def retranslateUi(self, ScanQRCodeDialog):
        #  _translate = QtCore.QCoreApplication.translate
        ScanQRCodeDialog.setWindowTitle(_("Add address from QRCode"))
        self.addressLabel.setText(_("Address"))
import tikka.slots.pyqt.resources.icons.index_rc
