# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'tikka/slots/pyqt/resources/gui/windows/configuration.ui'
#
# Created by: PyQt5 UI code generator 5.15.9
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_ConfigurationDialog(object):
    def setupUi(self, ConfigurationDialog):
        ConfigurationDialog.setObjectName("ConfigurationDialog")
        ConfigurationDialog.resize(418, 346)
        ConfigurationDialog.setLocale(QtCore.QLocale(QtCore.QLocale.English, QtCore.QLocale.UnitedStates))
        self.verticalLayoutWidget = QtWidgets.QWidget(ConfigurationDialog)
        self.verticalLayoutWidget.setGeometry(QtCore.QRect(9, 10, 401, 331))
        self.verticalLayoutWidget.setObjectName("verticalLayoutWidget")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.verticalLayoutWidget)
        self.verticalLayout.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout.setObjectName("verticalLayout")
        self.imageLabel = QtWidgets.QLabel(self.verticalLayoutWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.imageLabel.sizePolicy().hasHeightForWidth())
        self.imageLabel.setSizePolicy(sizePolicy)
        self.imageLabel.setMaximumSize(QtCore.QSize(100, 100))
        self.imageLabel.setSizeIncrement(QtCore.QSize(0, 0))
        self.imageLabel.setBaseSize(QtCore.QSize(0, 0))
        self.imageLabel.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.imageLabel.setText("")
        self.imageLabel.setPixmap(QtGui.QPixmap(":/images/config"))
        self.imageLabel.setScaledContents(True)
        self.imageLabel.setObjectName("imageLabel")
        self.verticalLayout.addWidget(self.imageLabel, 0, QtCore.Qt.AlignHCenter)
        self.groupBoxLanguage = QtWidgets.QGroupBox(self.verticalLayoutWidget)
        self.groupBoxLanguage.setStyleSheet("")
        self.groupBoxLanguage.setLocale(QtCore.QLocale(QtCore.QLocale.English, QtCore.QLocale.UnitedStates))
        self.groupBoxLanguage.setFlat(False)
        self.groupBoxLanguage.setObjectName("groupBoxLanguage")
        self.verticalLayout_4 = QtWidgets.QVBoxLayout(self.groupBoxLanguage)
        self.verticalLayout_4.setContentsMargins(-1, -1, -1, 0)
        self.verticalLayout_4.setSpacing(0)
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.languageRadioButtonsLayout = QtWidgets.QVBoxLayout()
        self.languageRadioButtonsLayout.setSpacing(0)
        self.languageRadioButtonsLayout.setObjectName("languageRadioButtonsLayout")
        self.languageHelpLabel = QtWidgets.QLabel(self.groupBoxLanguage)
        font = QtGui.QFont()
        font.setItalic(True)
        self.languageHelpLabel.setFont(font)
        self.languageHelpLabel.setObjectName("languageHelpLabel")
        self.languageRadioButtonsLayout.addWidget(self.languageHelpLabel)
        self.verticalLayout_4.addLayout(self.languageRadioButtonsLayout)
        self.verticalLayout.addWidget(self.groupBoxLanguage)
        self.groupBoxCurrency = QtWidgets.QGroupBox(self.verticalLayoutWidget)
        self.groupBoxCurrency.setStyleSheet("")
        self.groupBoxCurrency.setLocale(QtCore.QLocale(QtCore.QLocale.English, QtCore.QLocale.UnitedStates))
        self.groupBoxCurrency.setFlat(False)
        self.groupBoxCurrency.setObjectName("groupBoxCurrency")
        self.verticalLayout_5 = QtWidgets.QVBoxLayout(self.groupBoxCurrency)
        self.verticalLayout_5.setContentsMargins(-1, 0, -1, 0)
        self.verticalLayout_5.setSpacing(0)
        self.verticalLayout_5.setObjectName("verticalLayout_5")
        self.currencyRadioButtonsLayout = QtWidgets.QVBoxLayout()
        self.currencyRadioButtonsLayout.setSpacing(0)
        self.currencyRadioButtonsLayout.setObjectName("currencyRadioButtonsLayout")
        self.verticalLayout_5.addLayout(self.currencyRadioButtonsLayout)
        self.verticalLayout.addWidget(self.groupBoxCurrency)
        self.randomConnectioncheckBox = QtWidgets.QCheckBox(self.verticalLayoutWidget)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.randomConnectioncheckBox.setFont(font)
        self.randomConnectioncheckBox.setChecked(True)
        self.randomConnectioncheckBox.setObjectName("randomConnectioncheckBox")
        self.verticalLayout.addWidget(self.randomConnectioncheckBox)
        self.buttonBox = QtWidgets.QDialogButtonBox(self.verticalLayoutWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.buttonBox.sizePolicy().hasHeightForWidth())
        self.buttonBox.setSizePolicy(sizePolicy)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.Cancel|QtWidgets.QDialogButtonBox.Save)
        self.buttonBox.setCenterButtons(True)
        self.buttonBox.setObjectName("buttonBox")
        self.verticalLayout.addWidget(self.buttonBox)

        self.retranslateUi(ConfigurationDialog)
        QtCore.QMetaObject.connectSlotsByName(ConfigurationDialog)

    def retranslateUi(self, ConfigurationDialog):
        #  _translate = QtCore.QCoreApplication.translate
        ConfigurationDialog.setWindowTitle(_("Configuration"))
        self.groupBoxLanguage.setTitle(_("Language"))
        self.languageHelpLabel.setText(_("Restart application to apply language change"))
        self.groupBoxCurrency.setTitle(_("Currency"))
        self.randomConnectioncheckBox.setText(_("Connect randomly to a node at start"))
import tikka.slots.pyqt.resources.icons.index_rc
